@@ -10,19 +10,20 @@
 import logging
 import os
 import sys
+import warnings
 
 import click
 
 import pynitrokey
 import pynitrokey.fido2.operations
-from pynitrokey.cli.pro import pro
 from pynitrokey.cli.fido2 import fido2
 from pynitrokey.cli.nethsm import nethsm
+from pynitrokey.cli.pro import pro
 from pynitrokey.cli.start import start
 from pynitrokey.cli.storage import storage
 from pynitrokey.confconsts import LOG_FN, LOG_FORMAT
 
-#from . import _patches  # noqa  (since otherwise "unused")
+# from . import _patches  # noqa  (since otherwise "unused")
 
 
 def check_root():
@@ -37,7 +38,9 @@ def check_root():
                 "We suggest using: https://raw.githubusercontent.com/Nitrokey/libnitrokey/master/data/41-nitrokey.rules"
             )
             print()
-            print("For more information, see: https://www.nitrokey.com/documentation/installation#p:nitrokey-fido2&os:linux")
+            print(
+                "For more information, see: https://www.nitrokey.com/documentation/installation#p:nitrokey-fido2&os:linux"
+            )
 
 
 @click.group()
@@ -45,7 +48,10 @@ def nitropy():
     handler = logging.FileHandler(filename=LOG_FN, delay=True)
     logging.basicConfig(format=LOG_FORMAT, level=logging.DEBUG, handlers=[handler])
 
-    print("Nitrokey tool for Nitrokey FIDO2, Nitrokey Start & NetHSM", file=sys.stderr)
+    print(
+        "Nitrokey tool for Nitrokey FIDO2, Nitrokey Start, Nitrokey 3 & NetHSM",
+        file=sys.stderr,
+    )
     check_root()
 
 
@@ -65,12 +71,22 @@ def version():
 nitropy.add_command(version)
 
 
-@click.command()
-def ls():
-    """List Nitrokey keys (in firmware or bootloader mode)"""
-
+def _list():
     fido2.commands["list"].callback()
     start.commands["list"].callback()
 
 
+@click.command()
+def list():
+    """List Nitrokey keys (in firmware or bootloader mode)"""
+    _list()
+
+
+@click.command(hidden=True)
+def ls():
+    warnings.warn("The ls command is deprecated. Please use list instead.")
+    _list()
+
+
+nitropy.add_command(list)
 nitropy.add_command(ls)
