@@ -12,7 +12,9 @@ import sys
 from getpass import getpass
 from numbers import Number
 from threading import Event, Timer
-from typing import List
+from typing import List, Optional
+
+from tqdm import tqdm
 
 from pynitrokey.confconsts import (
     GH_ISSUES_URL,
@@ -38,6 +40,41 @@ def from_websafe(data):
     return data + "=="[: (3 * len(data)) % 4]
 
 
+class ProgressBar:
+    """
+    Helper class for progress bars where the total length of the progress bar
+    is not available before the first iteration.
+    """
+
+    def __init__(self, **kwargs) -> None:
+        self.bar: Optional[tqdm] = None
+        self.kwargs = kwargs
+        self.sum = 0
+
+    def __enter__(self) -> "ProgressBar":
+        return self
+
+    def __exit__(self, exc_type, exc_val, exc_tb) -> None:
+        self.close()
+
+    def update(self, n: int, total: int) -> None:
+        if not self.bar:
+            self.bar = tqdm(total=total, **self.kwargs)
+        self.bar.update(n)
+        self.sum += n
+
+    def update_sum(self, n: int, total: int) -> None:
+        if not self.bar:
+            self.bar = tqdm(total=total, **self.kwargs)
+        if n > self.sum:
+            self.bar.update(n - self.sum)
+            self.sum = n
+
+    def close(self) -> None:
+        if self.bar:
+            self.bar.close()
+
+
 class Timeout(object):
     """
     Utility class for adding a timeout to an event.
